import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class LoginForm extends StatefulWidget {
  @override
  _LoginFormState createState() => _LoginFormState();
}

class _LoginFormState extends State<LoginForm> {
  final formKey = GlobalKey();
  String _email, _password;

  @override
  Widget build(BuildContext context) {
    final myAuth = context.watch<AuthState>();
    return Form(
      key: formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          TextField(
            decoration: InputDecoration(
              labelText: "Email",
              icon: Icon(Icons.email_outlined),
              hintText: "example@email.com",
            ),
            onChanged: (text) {
              setState(() {
                _email = text;
              });
            },
          ),
          TextField(
            decoration: InputDecoration(
              labelText: "Password",
              icon: Icon(Icons.enhanced_encryption),
              hintText: "********",
            ),
            onChanged: (text) {
              setState(() {
                _password = text;
              });
            },
            obscureText: true,
          ),
          Container(
            padding: EdgeInsets.all(16),
            alignment: AlignmentDirectional.centerEnd,
            child: TextButton(
              onPressed: () {
                Navigator.pushNamed(context, "forgot");
              },
              child: Text(
                "I forgot my password",
                style: TextStyle(
                  fontStyle: FontStyle.italic,
                ),
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: ElevatedButton(
              child: Text("Login"),
              onPressed: () {
                FirebaseAuth.instance
                    .signInWithEmailAndPassword(
                        email: _email, password: _password)
                    .then((value) {
                  if (value.additionalUserInfo.isNewUser) {
                    //add to the database
                    value.user.sendEmailVerification();
                  }
                  FirebaseAnalytics()
                      .logLogin(loginMethod: "email_and_password");
                  if (myAuth.navData == null) {
                    Navigator.of(context).pushNamed("profile");
                  } else {
                    Navigator.of(context)
                        .pushNamed("joinothers", arguments: myAuth.navData);
                  }
                }).catchError((err, stack) {
                  FirebaseCrashlytics.instance.recordError(err, stack);
                  ScaffoldMessenger.of(context).showSnackBar(SnackBar(
                    content: Text(err.toString()),
                  ));
                });
              },
            ),
          ),
          Divider(
            indent: 24,
            endIndent: 24,
            thickness: 2,
          ),
          Text(
            "or",
            textAlign: TextAlign.center,
            style: TextStyle(fontStyle: FontStyle.italic),
          ),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                ElevatedButton.icon(
                  label: Text(
                    " Continue with FaceBook",
                  ),
                  style: ElevatedButton.styleFrom(
                    primary: Colors.lightBlue,
                  ),
                  onPressed: () {
                    myAuth.signInWithFacebook().then((value) {
                      if (value.additionalUserInfo.isNewUser) {
                        //add to the database
                        value.user.sendEmailVerification();
                      }
                      if (myAuth.navData == null) {
                        Navigator.of(context).pushNamed("profile");
                      } else {
                        Navigator.of(context)
                            .pushNamed("joinothers", arguments: myAuth.navData);
                      }
                    }).catchError((error, stack) {
                      FirebaseCrashlytics.instance.recordError(error, stack);
                      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
                        content: Text(error.toString()),
                      ));
                    });
                  },
                  icon: Icon(Entypo.facebook),
                ),
                ElevatedButton.icon(
                  label: Text(" Continue with Google"),
                  onPressed: () {
                    myAuth.signInWithGoogle().then((value) {
                      if (value.additionalUserInfo.isNewUser) {
                        //add to the database
                        value.user.sendEmailVerification();
                      }
                      if (myAuth.navData == null) {
                        Navigator.of(context).pushNamed("profile");
                      } else {
                        Navigator.of(context)
                            .pushNamed("joinothers", arguments: myAuth.navData);
                      }
                    }).catchError((error, stack) {
                      print(error);
                      FirebaseCrashlytics.instance.recordError(error, stack);
                      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
                        content: Text(error.toString()),
                      ));
                    });
                  },
                  icon: Icon(FontAwesome5.google_plus),
                  style: ElevatedButton.styleFrom(
                    primary: Colors.red[300],
                  ),
                )
              ],
            ),
          ),
        ],
      ),
      autovalidateMode: AutovalidateMode.always,
    );
  }
}
