import 'package:firebase_auth/firebase_auth.dart';
import 'package:provider/provider.dart';
import 'package:flutter/material.dart';

class RegistrationForm extends StatefulWidget {
  @override
  _RegistrationFormState createState() => _RegistrationFormState();
}

class _RegistrationFormState extends State<RegistrationForm> {
  final regFormKey = GlobalKey(debugLabel: "Registration Form");
  String _email, _password;
  bool _nTC = false;
  @override
  Widget build(BuildContext context) {
    final myAuth = context.watch<AuthState>();
    return Form(
      key: regFormKey,
      child: ListView(
        children: [
          Image.asset("assets/images/icon.png"),
          TextField(
            decoration: InputDecoration(
              labelText: "Email",
              icon: Icon(Icons.email),
              hintText: "example@email.com",
            ),
            onChanged: (text) {
              setState(() {
                _email = text;
              });
            },
          ),
          TextField(
            decoration: InputDecoration(
              labelText: "Password",
              icon: Icon(Icons.enhanced_encryption),
              hintText: "********",
            ),
            onChanged: (text) {
              setState(() {
                _password = text;
              });
            },
            obscureText: true,
          ),
          CheckboxListTile(
            value: _nTC,
            title: Text("I agree to terms and conditions"),
            secondary: IconButton(
              icon: Icon(FontAwesome5.hammer),
              onPressed: () {
                Navigator.of(context).pushNamed("legal");
              },
            ),
            onChanged: (value) {
              setState(() {
                _nTC = value;
              });
            },
          ),
          Padding(
            padding: EdgeInsets.symmetric(vertical: 30),
          ),
          ElevatedButton.icon(
            icon: Icon(Icons.account_box),
            onPressed: _nTC
                ? () {
                    FirebaseAuth.instance
                        .createUserWithEmailAndPassword(
                            email: _email, password: _password)
                        .then((value) {
                      value.user.sendEmailVerification();
                      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
                        content: Text("Success"),
                      ));
                      if (myAuth.navData == null) {
                        Navigator.of(context).pushNamed("profile");
                      } else {
                        Navigator.of(context)
                            .pushNamed("joinothers", arguments: myAuth.navData);
                      }
                    }).catchError((err) {
                      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
                        content: Text("Something went wrong \n $err"),
                        backgroundColor: Colors.red,
                      ));
                    });
                  }
                : null,
            label: Text("Register"),
          )
        ],
      ),
    );
  }
}
